# AutomationScriptFilterWrapper

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**filter** | [**GenericStringFilter**](GenericStringFilter.md) |  | [optional] 
**save_password** | **bool** |  | [optional] 
**script** | [**AutomationScript**](AutomationScript.md) |  | [optional] 

[[Back to Model list]](README.md#documentation-for-models) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to README]](README.md)


